.. _operators-api:

Matrix operators
================

..  automodule:: tidyms2.operators
    :show-inheritance:
    :members:
        SampleFilter,
        FeatureFilter,
        BlankCorrector,
        MetricsFilter,
        CVFilter,
        DetectionRateFilter,
        CorrelationFilter,
    :exclude-members: model_computed_fields, model_config, model_fields